@@ -1,14 +1,14 @@
-from . import components
-from . import source_parameters
+from . import components, source_parameters
 from ._component_label import ComponentLabel
 from ._contour import tabulate_density
 from .models import model_registry
+from .solar_irradiance_models import solar_irradiance_model_registry
 from .zodipy import Zodipy
 
-
 __all__ = (
     "Zodipy",
     "model_registry",
+    "solar_irradiance_model_registry",
     "components",
     "source_parameters",
     "tabulate_density",
