@@ -1,7 +1,8 @@
 from enum import Enum
 
+
 class ComponentLabel(Enum):
-    """Labels representing the Interplanetary Dust components in the DIRBE model."""
+    """Labels representing the components in the DIRBE model."""
 
     CLOUD = "cloud"
     BAND1 = "band1"
