@@ -12,49 +12,58 @@ pointing to Earth from the Sun.
 
 from __future__ import annotations
 
-from astropy.coordinates import HeliocentricMeanEcliptic, get_body
 import astropy.units as u
-from astropy.time import Time
 import numpy as np
+from astropy.coordinates import HeliocentricMeanEcliptic, get_body
+from astropy.time import Time
 from numpy.typing import NDArray
 
-
-DISTANCE_FROM_EARTH_TO_L2 = 0.009896235034000056
+DISTANCE_FROM_EARTH_TO_L2 = 0.009896235034000056 * u.AU
 
 
-def get_earth_position(time_of_observation: Time) -> NDArray[np.floating]:
+def get_obs_earth_positions(
+    obs: str, obs_time: Time, obs_pos: u.Quantity[u.AU] | None
+) -> tuple[NDArray[np.floating], NDArray[np.floating]]:
+
+    earth_position = _get_earth_position(obs_time)
+    if obs_pos is None:
+        obs_pos = _get_observer_position(obs, obs_time, earth_position)
+
+    return obs_pos.reshape(3, 1).value, earth_position.reshape(3, 1).value
+
+
+def _get_earth_position(obs_time: Time) -> u.Quantity[u.AU]:
     """Returns the position of the Earth given an ephemeris and observation time."""
 
-    earth_skycoordinate = get_body("earth", time_of_observation)
+    earth_skycoordinate = get_body("earth", obs_time)
     earth_skycoordinate = earth_skycoordinate.transform_to(HeliocentricMeanEcliptic)
-    earth_position = earth_skycoordinate.cartesian.xyz.to(u.AU)
 
-    return earth_position.reshape(3, 1).value
+    return earth_skycoordinate.cartesian.xyz.to(u.AU)
 
 
-def get_observer_position(
-    observer: str, time_of_observation: Time, earth_position: NDArray[np.floating]
-) -> NDArray[np.floating]:
+def _get_observer_position(
+    obs: str, obs_time: Time, earth_pos: u.Quantity[u.AU]
+) -> u.Quantity[u.AU]:
     """Returns the position of the Earth and the observer."""
 
-    if observer.lower() == "semb-l2":
-        return _get_sun_earth_moon_barycenter(earth_position)
+    if obs.lower() == "semb-l2":
+        return _get_sun_earth_moon_barycenter(earth_pos)
 
-    observer_skycoordinate = get_body(observer, time_of_observation)
+    observer_skycoordinate = get_body(obs, obs_time)
     observer_skycoordinate = observer_skycoordinate.transform_to(
         HeliocentricMeanEcliptic
     )
-    observer_position = observer_skycoordinate.cartesian.xyz.to(u.AU)
 
-    return observer_position.reshape(3, 1).value
+    return observer_skycoordinate.cartesian.xyz.to(u.AU)
 
 
 def _get_sun_earth_moon_barycenter(
-    earth_position: NDArray[np.floating],
-) -> NDArray[np.floating]:
+    earth_position: u.Quantity[u.AU],
+) -> u.Quantity[u.AU]:
     """Returns the approximated position of SEMB-L2 given Earth's position."""
 
     r_earth = np.linalg.norm(earth_position)
+
     earth_unit_vector = earth_position / r_earth
     semb_l2_length = r_earth + DISTANCE_FROM_EARTH_TO_L2
 
