@@ -2,17 +2,19 @@ from __future__ import annotations
 
 from dataclasses import dataclass, field
 
-from astropy.units import Quantity
 import astropy.units as u
 import numpy as np
 from scipy.interpolate import interp1d
 
 from ._component import Component
 from ._component_label import ComponentLabel
-from .source_parameters import T_0_DIRBE, DELTA_DIRBE
+
+from._solar_irradiance_model import SolarIrradianceModel
+from .solar_irradiance_models import solar_irradiance_model_registry
+from .source_parameters import DELTA_DIRBE, T_0_DIRBE
 
 
-@dataclass(frozen=True)
+@dataclass
 class Model:
     """Interplanetary Dust model.
 
@@ -22,62 +24,42 @@ class Model:
     """
 
     name: str
-    components: dict[ComponentLabel, Component]
-    spectrum: Quantity[u.Hz] | Quantity[u.m]
+    comps: dict[ComponentLabel, Component]
+    spectrum: u.Quantity[u.Hz] | u.Quantity[u.m]
     emissivities: dict[ComponentLabel, tuple[float, ...]]
     albedos: dict[ComponentLabel, tuple[float, ...]] | None = None
+    solar_irradiance_model: SolarIrradianceModel | None = None
     phase_coefficients: list[tuple[float, ...]] | None = None
     T_0: float = T_0_DIRBE
     delta: float = DELTA_DIRBE
 
     @property
-    def n_components(self) -> int:
-        return len(self.components)
+    def n_comps(self) -> int:
+        return len(self.comps)
 
-    def validate_frequency(
-        self, frequency: Quantity[u.GHz] | Quantity[u.m], extrapolate: bool
-    ) -> None:
-        """
-        Raises ValueError if the requested frequency is out of range the range
-        covered by the model.
-        """
-
-        if extrapolate:
-            return
-
-        frequency = frequency.to(self.spectrum.unit, equivalencies=u.spectral())
-        spectrum_min, spectrum_max = self.spectrum.min(), self.spectrum.max()
-        if not (spectrum_min <= frequency <= spectrum_max):
-            raise ValueError(
-                f"model {self.name!r} is only valid in the [{spectrum_min.value},"
-                f" {spectrum_max.value}] {self.spectrum.unit} range."
-            )
-
-    def get_source_parameters(
-        self,
-        component_label: ComponentLabel,
-        frequency: Quantity[u.GHz] | Quantity[u.m],
+    def interpolate_source_parameters(
+        self, comp_label: ComponentLabel, freq: u.Quantity[u.GHz] | u.Quantity[u.m]
     ) -> tuple[float, float, tuple[float, float, float]]:
         """
         Returns interpolated/extrapolated source parameters for a component
         given a frequency.
         """
 
-        frequency = frequency.to(self.spectrum.unit, equivalencies=u.spectral())
+        freq = freq.to(self.spectrum.unit, equivalencies=u.spectral())
         emissivity_interpolator = interp1d(
             x=self.spectrum,
-            y=self.emissivities[component_label],
+            y=self.emissivities[comp_label],
             fill_value="extrapolate",
         )
-        emissivity = emissivity_interpolator(frequency)
+        emissivity = emissivity_interpolator(freq)
 
         if self.albedos is not None:
             albedo_interpolator = interp1d(
                 x=self.spectrum,
-                y=self.albedos[component_label],
+                y=self.albedos[comp_label],
                 fill_value="extrapolate",
             )
-            albedo = albedo_interpolator(frequency)
+            albedo = albedo_interpolator(freq)
         else:
             albedo = 0.0
 
@@ -87,18 +69,18 @@ class Model:
                 y=np.asarray(self.phase_coefficients),
                 fill_value="extrapolate",
             )
-            phase_coefficient = phase_coefficient_interpolator(frequency)
+            phase_coefficient = phase_coefficient_interpolator(freq)
         else:
             phase_coefficient = [0.0 for _ in range(3)]
 
         return emissivity, albedo, tuple(phase_coefficient)
 
     def __repr__(self) -> str:
-        component_names = [component_label.value for component_label in self.components]
+        comp_names = [comp_label.value for comp_label in self.comps]
         repr = f"{type(self).__name__}( \n"
         repr += f"   name: {self.name!r},\n"
         repr += "   components: (\n"
-        for name in component_names:
+        for name in comp_names:
             repr += f"      {name!r},\n"
         repr += "   ),\n"
         repr += "   thermal: True,\n"
@@ -123,10 +105,11 @@ class ModelRegistry:
     def register_model(
         self,
         name: str,
-        components: dict[ComponentLabel, Component],
-        spectrum: Quantity[u.Hz] | Quantity[u.m],
+        comps: dict[ComponentLabel, Component],
+        spectrum: u.Quantity[u.Hz] | u.Quantity[u.m],
         emissivities: dict[ComponentLabel, tuple[float, ...]],
         albedos: dict[ComponentLabel, tuple[float, ...]] | None = None,
+        solar_irradiance_model: str | None = None,
         phase_coefficients: list[tuple[float, ...]] | None = None,
         T_0: float = T_0_DIRBE,
         delta: float = DELTA_DIRBE,
@@ -141,7 +124,7 @@ class ModelRegistry:
         name
             String representing the name of the model. This is the name that is
             used for the 'model' argument when initializing `Zodipy`.
-        components
+        comps
             Dict mapping `CompLabel`s to `Component` classes.
         spectrum
             The spectrum (frequency or length units) corresponding to the
@@ -152,28 +135,42 @@ class ModelRegistry:
         albedos
             Albedo factor fits for each IPD component at the frequencies
             corresponding to 'spectrum'.
+        solar_irradiance_model
+            Model for the solar irradiance.
         phase_coefficients
             Coefficient fits for the phase function at the frequencies
             corresponding to 'spectrum'.
         T_0
-            Interplanetary temperature at 1 AU. Defaults to the DIRBE model value.
+            Dust grain temperature at 1 AU. Defaults to the DIRBE model value.
         delta
-            Interplanetary temperatue powerlaw parameter describing how the
-            interplanetary temperature falls with radial distance from the Sun.
-            Defaults to the DIRBE model value.
+            Dust grain temperature powerlaw parameter describing how the
+            temperature falls with radial distance from the Sun. Defaults to the
+            DIRBE model value.
         """
 
         if (name := name.lower()) in self._registry:
             raise ValueError(f"a model by the name {name!s} is already registered.")
 
+        if solar_irradiance_model is not None:
+            solar_model = solar_irradiance_model_registry.get_model(
+                solar_irradiance_model
+            )
+        else:
+            solar_model = solar_irradiance_model
+
+        if albedos is not None and solar_irradiance_model is None:
+            raise ValueError(
+                "albedos are provided but no solar irradiance model is provided."
+            )
         self._registry[name] = Model(
             name=name,
-            components=components,
+            comps=comps,
             spectrum=spectrum,
             emissivities=emissivities,
             T_0=T_0,
             delta=delta,
             albedos=albedos,
+            solar_irradiance_model=solar_model,
             phase_coefficients=phase_coefficients,
         )
 
